diff mbox

mmc: rename ddr to uhs in ios structure to indicate usage

Message ID 52D7AFC3-31CF-4938-90EC-3BB4B701CCD4@marvell.com (mailing list archive)
State New, archived
Headers show

Commit Message

Philip Rakity Feb. 14, 2011, 7:13 a.m. UTC
None
diff --git a/drivers/mmc/core/core.h b/drivers/mmc/core/core.h
index 20b1c08..2c9f456 100644
--- a/drivers/mmc/core/core.h
+++ b/drivers/mmc/core/core.h
@@ -38,7 +38,7 @@  void mmc_ungate_clock(struct mmc_host *host);
 void mmc_set_ungated(struct mmc_host *host);
 void mmc_set_bus_mode(struct mmc_host *host, unsigned int mode);
 void mmc_set_bus_width(struct mmc_host *host, unsigned int width);
-void mmc_set_bus_width_ddr(struct mmc_host *host, unsigned int width,
+void mmc_set_bus_width_uhs(struct mmc_host *host, unsigned int width,
 			   unsigned int ddr);
 u32 mmc_select_voltage(struct mmc_host *host, u32 ocr);
 void mmc_set_timing(struct mmc_host *host, unsigned int timing);
diff --git a/drivers/mmc/core/mmc.c b/drivers/mmc/core/mmc.c
index 6c5d3d4..00b9cb5 100644
--- a/drivers/mmc/core/mmc.c
+++ b/drivers/mmc/core/mmc.c
@@ -640,7 +640,7 @@  static int mmc_init_card(struct mmc_host *host, u32 ocr,
 					 EXT_CSD_BUS_WIDTH,
 					 ext_csd_bits[idx][0]);
 			if (!err) {
-				mmc_set_bus_width_ddr(card->host,
+				mmc_set_bus_width_uhs(card->host,
 						      bus_width, MMC_SDR_MODE);
 				/*
 				 * If controller can't handle bus width test,
@@ -667,7 +667,7 @@  static int mmc_init_card(struct mmc_host *host, u32 ocr,
 			goto free_card;
 		} else if (ddr) {
 			mmc_card_set_ddr_mode(card);
-			mmc_set_bus_width_ddr(card->host, bus_width, ddr);
+			mmc_set_bus_width_uhs(card->host, bus_width, ddr);
 		}
 	}
 
diff --git a/include/linux/mmc/host.h b/include/linux/mmc/host.h
index bcb793e..f11307e 100644
--- a/include/linux/mmc/host.h
+++ b/include/linux/mmc/host.h
@@ -51,7 +51,7 @@  struct mmc_ios {
 #define MMC_TIMING_MMC_HS	1
 #define MMC_TIMING_SD_HS	2
 
-	unsigned char	ddr;			/* dual data rate used */
+	unsigned char	uhs;			/* uhs mode used (ddr - sdr) */
 
 #define MMC_SDR_MODE		0
 #define MMC_1_2V_DDR_MODE	1
diff mbox

Patch

diff --git a/drivers/mmc/core/core.c b/drivers/mmc/core/core.c
index d9fb0d3..cc67a37 100644
--- a/drivers/mmc/core/core.c
+++ b/drivers/mmc/core/core.c
@@ -712,13 +712,13 @@  void mmc_set_bus_mode(struct mmc_host *host, unsigned int mode)
 }
 
 /*
  * Change data bus width and DDR mode of a host.
  */
-void mmc_set_bus_width_ddr(struct mmc_host *host, unsigned int width,
-			   unsigned int ddr)
+void mmc_set_bus_width_uhs(struct mmc_host *host, unsigned int width,
+			   unsigned int uhs)
 {
 	host->ios.bus_width = width;
-	host->ios.ddr = ddr;
+	host->ios.uhs = uhs;
 	mmc_set_ios(host);
 }
 
@@ -727,7 +727,7 @@  void mmc_set_bus_width_ddr(struct mmc_host *host, unsigned int width,
  */
 void mmc_set_bus_width(struct mmc_host *host, unsigned int width)
 {
-	mmc_set_bus_width_ddr(host, width, MMC_SDR_MODE);
+	mmc_set_bus_width_uhs(host, width, MMC_SDR_MODE);
 }
 
 /**
@@ -712,13 +712,13 @@  void mmc_set_bus_mode(struct mmc_host *host, unsigned int mode)
 
 /*
- * Change data bus width and DDR mode of a host.
+ * Change data bus width and UHS mode of a host.
  */